@@ -38,20 +38,16 @@ struct Q_DECL_HIDDEN KisBaseNode::Private
     QMap<QString, KisKeyframeChannel*> keyframeChannels;
     QScopedPointer<KisScalarKeyframeChannel> opacityChannel;
 
-    bool systemLocked;
-    bool collapsed;
-    bool supportsLodMoves;
-    bool animated;
-    bool useInTimeline;
+    bool systemLocked {false};
+    bool collapsed {false};
+    bool supportsLodMoves {false};
+    bool animated {false};
+    bool useInTimeline {true};
+
     KisImageWSP image;
 
     Private(KisImageWSP image)
         : id(QUuid::createUuid())
-        , systemLocked(false)
-        , collapsed(false)
-        , supportsLodMoves(false)
-        , animated(false)
-        , useInTimeline(true)
         , image(image)
     {
     }
@@ -59,7 +55,6 @@ struct Q_DECL_HIDDEN KisBaseNode::Private
     Private(const Private &rhs)
         : compositeOp(rhs.compositeOp),
           id(QUuid::createUuid()),
-          systemLocked(false),
           collapsed(rhs.collapsed),
           supportsLodMoves(rhs.supportsLodMoves),
           animated(rhs.animated),
@@ -239,8 +234,10 @@ bool KisBaseNode::check(const KoProperties & properties) const
 }
 
 
-QImage KisBaseNode::createThumbnail(qint32 w, qint32 h)
+QImage KisBaseNode::createThumbnail(qint32 w, qint32 h, Qt::AspectRatioMode aspectRatioMode)
 {
+    Q_UNUSED(aspectRatioMode);
+
     try {
         QImage image(w, h, QImage::Format_ARGB32);
         image.fill(0);
@@ -251,9 +248,10 @@ QImage KisBaseNode::createThumbnail(qint32 w, qint32 h)
 
 }
 
-QImage KisBaseNode::createThumbnailForFrame(qint32 w, qint32 h, int time)
+QImage KisBaseNode::createThumbnailForFrame(qint32 w, qint32 h, int time, Qt::AspectRatioMode aspectRatioMode)
 {
     Q_UNUSED(time)
+    Q_UNUSED(aspectRatioMode);
     return createThumbnail(w, h);
 }
 
