@@ -196,14 +196,14 @@ void KoColorSpaceRegistry::init()
     KoPluginLoader::PluginsConfig config;
     config.whiteList = "ColorSpacePlugins";
     config.blacklist = "ColorSpacePluginsDisabled";
-    config.group = "calligra";
-    KoPluginLoader::instance()->load("Calligra/ColorSpace", "[X-Pigment-PluginVersion] == 28", config);
+    config.group = "krita";
+    KoPluginLoader::instance()->load("Krita/ColorSpace", "[X-Pigment-PluginVersion] == 28", config);
 
     KoPluginLoader::PluginsConfig configExtensions;
     configExtensions.whiteList = "ColorSpaceExtensionsPlugins";
     configExtensions.blacklist = "ColorSpaceExtensionsPluginsDisabled";
-    configExtensions.group = "calligra";
-    KoPluginLoader::instance()->load("Calligra/ColorSpaceExtension", "[X-Pigment-PluginVersion] == 28", configExtensions);
+    configExtensions.group = "krita";
+    KoPluginLoader::instance()->load("Krita/ColorSpaceExtension", "[X-Pigment-PluginVersion] == 28", configExtensions);
 
 
     dbgPigment << "Loaded the following colorspaces:";
@@ -484,8 +484,6 @@ const KoColorSpace * KoColorSpaceRegistry::Private::colorSpace1(const QString &c
         const KoColorProfile *profile =
             profileForCsIdWithFallbackImpl(csID, profileName);
 
-        // until kis_asert.h is not available in 3.1, use this combo
-        Q_ASSERT(profile);
         if (!profile) return 0;
 
         cs = lazyCreateColorSpaceImpl(csID, profile);
