@@ -27,6 +27,7 @@
 #include "KisResourceServerProvider.h"
 #include <kis_canvas_resource_provider.h>
 #include <KoTriangleColorSelector.h>
+#include "KoColorDisplayRendererInterface.h"
 #include <KisVisualColorSelector.h>
 #include <kis_config_notifier.h>
 #include <QtGui>
@@ -170,16 +171,6 @@ KisPopupPalette::KisPopupPalette(KisViewManager* viewManager, KisCoordinatesConv
     connect(m_resourceManager, SIGNAL(updatePalettes()), SLOT(slotUpdate()));
     connect(m_resourceManager, SIGNAL(hidePalettes()), SLOT(slotHide()));
 
-    // This is used to handle a bug:
-    // If pop up palette is visible and a new colour is selected, the new colour
-    // will be added when the user clicks on the canvas to hide the palette
-    // In general, we want to be able to store recent color if the pop up palette
-    // is not visible
-    m_timer.setSingleShot(true);
-    connect(this, SIGNAL(sigTriggerTimer()), this, SLOT(slotTriggerTimer()));
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(slotEnableChangeFGColor()));
-    connect(this, SIGNAL(sigEnableChangeFGColor(bool)), m_resourceManager, SIGNAL(sigEnableChangeColor(bool)));
-
     setCursor(Qt::ArrowCursor);
     setMouseTracking(true);
     setHoveredPreset(-1);
@@ -328,16 +319,6 @@ void KisPopupPalette::setSelectedColor(int x)
     m_selectedColor = x;
 }
 
-void KisPopupPalette::slotTriggerTimer()
-{
-    m_timer.start(750);
-}
-
-void KisPopupPalette::slotEnableChangeFGColor()
-{
-    emit sigEnableChangeFGColor(true);
-}
-
 void KisPopupPalette::slotZoomSliderChanged(int zoom) {
     emit zoomLevelChanged(zoom);
 }
@@ -424,9 +405,6 @@ void KisPopupPalette::showPopupPalette(bool show)
             KisSignalsBlocker b(zoomCanvasSlider);
             zoomCanvasSlider->setValue(m_coordinatesConverter->zoomInPercent()); // sync the zoom slider
         }
-        emit sigEnableChangeFGColor(!show);
-    } else {
-        emit sigTriggerTimer();
     }
     setVisible(show);
     m_brushHud->setVisible(show && m_brushHudButton->isChecked());
@@ -817,7 +795,7 @@ void KisPopupPalette::slotShowTagsPopup()
 
         QAction *action = menu.exec(QCursor::pos());
         if (action) {
-            m_resourceManager->setCurrentTag(action->text());
+            m_resourceManager->setCurrentTag(KLocalizedString::removeAcceleratorMarker(action->text()));
         }
     } else {
         QWhatsThis::showText(QCursor::pos(),
