@@ -66,6 +66,26 @@ public:
     /// set the specified rect as the area taken for @see cutoutOverlay
     void setCutoutOverlayRect(const QRect&rc);
 
+    /**
+     * keep track of if our scratchpad is in paint, pan, or color pick mode
+     * Set to true if there is a GUI controlling current mode
+     * If this is false, the modes are only changed with various mouse click shortcuts
+     */
+    void setModeManually(bool value);
+
+    /**
+     * @brief change the mode explicitly to paint, mix, or pan
+     * @param what mode to change it to
+     */
+    void setModeType(QString modeName);
+
+    /**
+     * @brief should the scratchpad zoom level stay in sync with canvas
+     * @param should we link zoom level
+     */
+    void linkCanvavsToZoomLevel(bool value);
+
+
     /// return the contents of the area under the cutoutOverlay rect
     QImage cutoutOverlay() const;
 
@@ -87,6 +107,8 @@ public Q_SLOTS:
     void fillBackground();
     void fillTransparent();
 
+    void setFillColor(QColor newColor);
+
     /// Fill the area with what is on your current canvas
     void fillLayer();
 
@@ -108,7 +130,12 @@ public Q_SLOTS:
      * Paint the icon of a custom image that is being loaded
      *
      */
-    void paintCustomImage(const QImage& loadedImage);
+    void paintCustomImage(const QImage & loadedImage);
+
+
+    void loadScratchpadImage(QImage image);
+
+    QImage copyScratchpadImageData();
 
 private Q_SLOTS:
     void setOnScreenResolution(qreal scaleX, qreal scaleY);
@@ -153,9 +180,13 @@ private:
 
     KoColor m_defaultColor;
     Mode m_toolMode;
+    bool isModeManuallySet;
+    bool isMouseDown;
+    bool linkCanvasZoomLevel;
     KisPaintLayerSP m_paintLayer;
     const KoColorProfile* m_displayProfile;
     QCursor m_cursor;
+    QCursor m_colorPickerCursor;
     QRect m_cutoutOverlay;
     QBrush m_checkBrush;
     KisCanvasResourceProvider* m_resourceProvider;
