@@ -82,6 +82,7 @@
 #include "kis_assert.h"
 #include "kis_global.h"
 #include "kis_debug.h"
+#include "krita_utils.h"
 
 #include <QVector2D>
 
@@ -145,6 +146,11 @@ public:
         KoShapeRubberSelectStrategy::paint(painter, converter);
     }
 
+    void cancelInteraction() override
+    {
+        tool()->canvas()->updateCanvas(selectedRectangle() | tool()->decorationsRect());
+    }
+
     void finishInteraction(Qt::KeyboardModifiers modifiers = 0) override
     {
         Q_UNUSED(modifiers);
@@ -165,8 +171,7 @@ public:
                 selection->select(shape);
             }
 
-        defaultTool->repaintDecorations();
-        defaultTool->canvas()->updateCanvas(selectedRectangle());
+        tool()->canvas()->updateCanvas(selectedRectangle() | tool()->decorationsRect());
     }
 };
 #include <KoGradientBackground.h>
@@ -344,6 +349,9 @@ DefaultTool::DefaultTool(KoCanvasBase *canvas, bool connectToSelectedShapesProxy
 
     if (connectToSelectedShapesProxy) {
         connect(canvas->selectedShapesProxy(), SIGNAL(selectionChanged()), this, SLOT(updateActions()));
+
+        connect(canvas->selectedShapesProxy(), SIGNAL(selectionChanged()), this, SLOT(repaintDecorations()));
+        connect(canvas->selectedShapesProxy(), SIGNAL(selectionContentChanged()), this, SLOT(repaintDecorations()));
     }
 }
 
@@ -739,11 +747,8 @@ void DefaultTool::mouseMoveEvent(KoPointerEvent *event)
             if (inside != m_mouseWasInsideHandles || m_lastHandle != newDirection) {
                 m_lastHandle = newDirection;
                 m_mouseWasInsideHandles = inside;
-                //repaintDecorations();
             }
         } else {
-            /*if (m_lastHandle != KoFlake::NoHandle)
-                repaintDecorations(); */
             m_lastHandle = KoFlake::NoHandle;
             m_mouseWasInsideHandles = false;
 
@@ -780,9 +785,6 @@ void DefaultTool::mouseReleaseEvent(KoPointerEvent *event)
 {
     KoInteractionTool::mouseReleaseEvent(event);
     updateCursor();
-
-    // This makes sure the decorations that are shown are refreshed. especally the "T" icon
-    canvas()->updateCanvas(QRectF(0,0,canvas()->canvasWidget()->width(), canvas()->canvasWidget()->height()));
 }
 
 void DefaultTool::mouseDoubleClickEvent(KoPointerEvent *event)
@@ -865,11 +867,22 @@ void DefaultTool::keyPressEvent(QKeyEvent *event)
     }
 }
 
-void DefaultTool::repaintDecorations()
+QRectF DefaultTool::decorationsRect() const
 {
+    QRectF dirtyRect;
+
     if (koSelection() && koSelection()->count() > 0) {
-        canvas()->updateCanvas(handlesSize());
+        /// TODO: avoid cons_cast by implementing proper
+        ///       caching strategy inrecalcSelectionBox() and
+        ///       handlesSize()
+        dirtyRect = const_cast<DefaultTool*>(this)->handlesSize();
     }
+
+    if (canvas()->snapGuide()->isSnapping()) {
+        dirtyRect |= canvas()->snapGuide()->boundingRect();
+    }
+
+    return dirtyRect;
 }
 
 void DefaultTool::copy() const
@@ -1230,8 +1243,16 @@ void DefaultTool::selectionBooleanOp(int booleanOp)
     const int referenceShapeIndex = 0;
     KoShape *referenceShape = editableShapes[referenceShapeIndex];
 
+    KisCanvas2 *kisCanvas = static_cast<KisCanvas2 *>(canvas());
+    KIS_SAFE_ASSERT_RECOVER_RETURN(kisCanvas);
+    const QTransform booleanWorkaroundTransform =
+        KritaUtils::pathShapeBooleanSpaceWorkaround(kisCanvas->image());
+
     Q_FOREACH (KoShape *shape, editableShapes) {
-        srcOutlines << shape->absoluteTransformation().map(shape->outline());
+        srcOutlines <<
+            booleanWorkaroundTransform.map(
+            shape->absoluteTransformation().map(
+                shape->outline()));
     }
 
     if (booleanOp == BooleanUnion) {
@@ -1265,6 +1286,8 @@ void DefaultTool::selectionBooleanOp(int booleanOp)
         actionName = kundo2_i18n("Subtract Shapes");
     }
 
+    dstOutline = booleanWorkaroundTransform.inverted().map(dstOutline);
+
     KoShape *newShape = 0;
 
     if (!dstOutline.isEmpty()) {
@@ -1547,7 +1570,6 @@ KoInteractionStrategy *DefaultTool::createStrategy(KoPointerEvent *event)
 
     if (avoidSelection || (!shape && handle == KoFlake::NoHandle)) {
         if (!selectMultiple) {
-            repaintDecorations();
             selection->deselectAll();
         }
         return new SelectionInteractionStrategy(this, event->point, false);
@@ -1555,16 +1577,13 @@ KoInteractionStrategy *DefaultTool::createStrategy(KoPointerEvent *event)
 
     if (selection->isSelected(shape)) {
         if (selectMultiple) {
-            repaintDecorations();
             selection->deselect(shape);
         }
     } else if (handle == KoFlake::NoHandle) { // clicked on shape which is not selected
-        repaintDecorations();
         if (!selectMultiple) {
             selection->deselectAll();
         }
         selection->select(shape);
-        repaintDecorations();
         // tablet selection isn't precise and may lead to a move, preventing that
         if (event->isTabletEvent()) {
             return new NopInteractionStrategy(this);
